@@ -1,7 +1,6 @@
 #include "maxminddb_test_helper.h"
 
-void run_tests(int mode, const char *mode_desc)
-{
+void run_tests(int mode, const char *mode_desc) {
     const char *filename = "MaxMind-DB-test-metadata-pointers.mmdb";
     const char *path = test_database_path(filename);
     MMDB_s *mmdb = open_ok(path, mode, mode_desc);
@@ -9,7 +8,8 @@ void run_tests(int mode, const char *mode_desc)
 
     char *repeated_string = "Lots of pointers in metadata";
 
-    is(mmdb->metadata.database_type, repeated_string,
+    is(mmdb->metadata.database_type,
+       repeated_string,
        "decoded pointer database_type");
 
     for (uint16_t i = 0; i < mmdb->metadata.description.count; i++) {
@@ -24,8 +24,7 @@ void run_tests(int mode, const char *mode_desc)
     free(mmdb);
 }
 
-int main(void)
-{
+int main(void) {
     plan(NO_PLAN);
     for_all_modes(&run_tests);
     done_testing();
